Particle

Struct Particle 

pub struct Particle { /* private fields */ }
Single Particle struct. Contains the location and color. Because macroquad does not support 3 dimensional points or single pixels, a Particle is implemented as a small line. This is why it contains the end_location member, as it is used as the ending point of the line.

This design choice can be embraced fully when creating a particle system that operates on a continuous line by setting the end_location somewhere near the the next point of the particle system to imitate continuity.

Implementations

Source

impl Particle

pub fn new( (x, y, z): (f32, f32, f32), (r, g, b, a): (f32, f32, f32, f32), size: f32, length: f32, sloped: bool, ) -> Result<Self, String>

Instantiate a new Particle at (x, y, z) location with (r, g, b, a) color and s size, length l. sloped determines if the particle’s opacity fades out or not.

pub fn new_line( (x, y, z): (f32, f32, f32), (xe, ye, ze): (f32, f32, f32), (r, g, b, a): (f32, f32, f32, f32), length: f32, sloped: bool, ) -> Result<Self, String>

Instantiate a new Particle at (x, y, z) location and ending location (x, y, z) with (r, g, b, a) color, length l. sloped determines if the particle’s opacity fades out or not.

pub fn add_location(self, x: f32, y: f32, z: f32) -> Self

Add the x, y, z argument values to the location of Particle.

pub fn sub_location(self, x: f32, y: f32, z: f32) -> Self

Subtract the x, y, z argument values to the location of Particle.

pub fn set_location(&mut self, x: f32, y: f32, z: f32)

Set the location of the particle to x, y, z argument.

pub fn set_color(&mut self, r: f32, g: f32, b: f32, a: f32)

Set the color of the particle to r, g, b, a argument.

pub fn draw(&mut self) -> bool

Draw the Particle within the macroquad world coords. Returns true if Particle has surpassed its length, else false.

pub fn reset(&mut self)

Reset the ellapsed time for the Particle object